@@ -14,9 +14,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: mozilla-embed-find.cpp,v 1.10 2006/09/13 11:34:15 chpe Exp $
+ *  $Id: mozilla-embed-find.cpp 6952 2007-03-11 19:42:02Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -73,12 +73,13 @@ impl_find (EphyEmbedFind *efind,
 
 static EphyEmbedFindResult
 impl_find_again (EphyEmbedFind *efind,
-		   gboolean forward)
+		 gboolean forward,
+		 gboolean links_only)
 {
 	MozillaEmbedFind *find = MOZILLA_EMBED_FIND (efind);
 	MozillaEmbedFindPrivate *priv = find->priv;
 
-	return priv->find->FindAgain (forward);
+	return priv->find->FindAgain (forward, links_only);
 }
 
 static void
