@@ -13,9 +13,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $Id: ephy-bookmarks-editor.c 6796 2007-01-08 22:53:47Z diegoe $
+ * $Id: ephy-bookmarks-editor.c 7108 2007-07-01 14:04:43Z jhaitsma $
  */
 
 #include "config.h"
@@ -194,18 +194,15 @@ static const GtkActionEntry ephy_bookmark_popup_entries [] = {
 	{ "OpenInTab", STOCK_NEW_TAB, N_("Open in New _Tab"), "<shift><control>O",
 	  N_("Open the selected bookmark in a new tab"), 
 	  G_CALLBACK (cmd_open_bookmarks_in_tabs) },
-	{ "Rename", NULL, N_("_Rename..."), "F2",
+	{ "Rename", NULL, N_("_Rename…"), "F2",
 	  N_("Rename the selected bookmark or topic"), G_CALLBACK (cmd_rename) },
-	{ "Delete", GTK_STOCK_DELETE, N_("_Delete"), NULL,
-	  N_("Delete the selected bookmark or topic"), 
-	  G_CALLBACK (cmd_delete) },
 	{ "Properties", GTK_STOCK_PROPERTIES, N_("_Properties"), "<alt>Return",
 	  N_("View or modify the properties of the selected bookmark"), 
 	  G_CALLBACK (cmd_bookmark_properties) },
-	{ "Import", NULL, N_("_Import Bookmarks..."), NULL,
+	{ "Import", NULL, N_("_Import Bookmarks…"), NULL,
 	  N_("Import bookmarks from another browser or a bookmarks file"), 
 	  G_CALLBACK (cmd_bookmarks_import) },
-	{ "Export", NULL, N_("_Export Bookmarks..."), NULL,
+	{ "Export", NULL, N_("_Export Bookmarks…"), NULL,
 	  N_("Export bookmarks to a file"), 
 	  G_CALLBACK (cmd_bookmarks_export) },	  
 	{ "Close", GTK_STOCK_CLOSE, N_("_Close"), "<control>W",
@@ -222,7 +219,10 @@ static const GtkActionEntry ephy_bookmark_popup_entries [] = {
 	{ "Paste", GTK_STOCK_PASTE, N_("_Paste"), "<control>V",
 	  N_("Paste the clipboard"), 
 	  G_CALLBACK (cmd_paste) },
-	{ "SelectAll", NULL, N_("Select _All"), "<control>A",
+	{ "Delete", GTK_STOCK_DELETE, N_("_Delete"), "<control>T",
+	  N_("Delete the selected bookmark or topic"), 
+	  G_CALLBACK (cmd_delete) },
+	{ "SelectAll", GTK_STOCK_SELECT_ALL, N_("Select _All"), "<control>A",
 	  N_("Select all bookmarks or text"), 
 	  G_CALLBACK (cmd_select_all) },
 	
@@ -230,7 +230,7 @@ static const GtkActionEntry ephy_bookmark_popup_entries [] = {
 	{ "HelpContents", GTK_STOCK_HELP, N_("_Contents"), "F1",
 	  N_("Display bookmarks help"), 
 	  G_CALLBACK (cmd_help_contents) },
-	{ "HelpAbout", GNOME_STOCK_ABOUT, N_("_About"), NULL,
+	{ "HelpAbout", GTK_STOCK_ABOUT, N_("_About"), NULL,
 	  N_("Display credits for the web browser creators"),
 	  G_CALLBACK (window_cmd_help_about) },
 };
