@@ -13,9 +13,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-net-monitor.c,v 1.5.2.2 2006/09/13 11:48:52 chpe Exp $
+ *  $Id: ephy-net-monitor.c 7536 2007-10-18 19:15:57Z cosimoc $
  */
 
 #include "config.h"
@@ -111,6 +111,8 @@ ephy_net_monitor_check_network (EphyNetMonitor *monitor)
 	DBusMessage *message;
 	DBusPendingCall* reply;
 
+	if (priv->bus == NULL) return;
+
 	LOG ("EphyNetMonitor checking network");
 
 	/* ask to Network Manager if there is at least one active device */
@@ -149,19 +151,9 @@ filter_func (DBusConnection *connection,
 
 	if (dbus_message_is_signal (message,
 				    NM_DBUS_INTERFACE,
-				    "DeviceNoLongerActive"))
+				    "StateChange"))
 	{
-		LOG ("EphyNetMonitor catches DeviceNoLongerActive signal");
-
-		ephy_net_monitor_check_network (monitor);
-
-		return DBUS_HANDLER_RESULT_HANDLED;
-	}
-	if (dbus_message_is_signal (message,
-				    NM_DBUS_INTERFACE,
-				    "DeviceNowActive"))
-	{
-		LOG ("EphyNetMonitor catches DeviceNowActive signal");
+		LOG ("EphyNetMonitor catches StateChange signal");
 
 		ephy_net_monitor_check_network (monitor);
 
@@ -248,13 +240,16 @@ ephy_net_monitor_startup (EphyNetMonitor *monitor)
 
 	ephy_net_monitor_attach_to_dbus (monitor);
 
-	/* DBUS may disconnect us at any time. So listen carefully to it */
-	g_signal_connect (dbus, "connected",  
-			  G_CALLBACK (connect_to_system_bus_cb), monitor);
-	g_signal_connect (dbus, "disconnected",  
-			  G_CALLBACK (disconnect_from_system_bus_cb), monitor);
+	if (monitor->priv->bus != NULL)
+       	{
+		/* DBUS may disconnect us at any time. So listen carefully to it */
+		g_signal_connect (dbus, "connected",  
+				  G_CALLBACK (connect_to_system_bus_cb), monitor);
+		g_signal_connect (dbus, "disconnected",  
+				  G_CALLBACK (disconnect_from_system_bus_cb), monitor);
 
-	ephy_net_monitor_check_network (monitor);
+		ephy_net_monitor_check_network (monitor);
+	}
 }
 
 static void
